@@ -76,14 +76,11 @@ def _computeIsText(string):
     """
     is_text = False
 
-    if (string):
-        char = unicode (string, "UTF-8")
-        if (char > 0 and  _unicharIsPrint (char)):
+    if string:
+        if _unicharIsPrint(string):
             is_text = True
         else:
             is_text = False
-    else:
-        is_text = False
 
     return is_text
 
@@ -297,6 +294,14 @@ class Script(default.Script):
             if role == pyatspi.ROLE_DIALOG:
                 return
 
+            if role == pyatspi.ROLE_MENU_ITEM and not event.source.name \
+               and not self.utilities.labelsForObject(event.source):
+                isRealFocus = lambda x: x and x.getRole() == pyatspi.ROLE_SLIDER
+                descendant = pyatspi.findDescendant(event.source, isRealFocus)
+                if descendant:
+                    orca.setLocusOfFocus(event, descendant)
+                    return
+
             # This is to present dialog boxes which are, to the user, newly
             # activated. And if something is claiming to be focused that is
             # not in a dialog, that's good to know as well, so update our
